=== modified file 'ChangeLog'
--- ChangeLog	2006-07-31 18:17:48 +0000
+++ ChangeLog	2006-08-01 16:16:31 +0000
@@ -1,3 +1,14 @@
+2006-08-01  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
+
+    * olive/frontend/gtk/push.py: now the number of pushed revisions gets
+      displayed (Fixed: #54698)
+    * olive/backend/info.py: added is_checkout()
+    * olive/frontend/gtk/commit.py: local commit checkbox shows up only if the
+      current directory is a checkout
+    * olive/backend/fileops.py: upgraded to new API (compare_trees deprecated)
+    * many files: the cursor changes to a watch when performing time consuming
+      operations (Fixed: #54015)
+
 2006-07-31  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
 
     * Back from holiday.

=== modified file 'olive.glade'
--- olive.glade	2006-07-31 18:17:48 +0000
+++ olive.glade	2006-08-01 16:16:31 +0000
@@ -696,7 +696,6 @@
 
       <child>
 	<widget class="GtkCheckButton" id="checkbutton_commit_local">
-	  <property name="visible">True</property>
 	  <property name="can_focus">True</property>
 	  <property name="label" translatable="yes">_Local only commit (works in bound branches)</property>
 	  <property name="use_underline">True</property>

=== modified file 'olive/backend/fileops.py'
--- olive/backend/fileops.py	2006-07-21 18:18:20 +0000
+++ olive/backend/fileops.py	2006-08-01 16:16:31 +0000
@@ -135,6 +135,7 @@
     
     :return: renamed | added | removed | modified | unchanged | unknown
     """
+    import bzrlib
     from bzrlib.delta import compare_trees
     from bzrlib.workingtree import WorkingTree
     
@@ -163,10 +164,15 @@
     rel = '/'.join(fpcopy)
     #print "DEBUG: rel =", rel
     
-    delta = compare_trees(old_tree=tree2,
-                          new_tree=tree1,
-                          want_unchanged=True,
-                          specific_files=[rel])
+    if bzrlib.version_info[1] < 9:
+        delta = compare_trees(old_tree=tree2,
+                              new_tree=tree1,
+                              want_unchanged=True,
+                              specific_files=[rel])
+    else:
+        delta = tree1.changes_from(tree2,
+                                   want_unchanged=True,
+                                   specific_files=[rel])
     
     """ Debug information (could be usable in the future, so didn't cut out)
     print "DEBUG: delta.renamed:"

=== modified file 'olive/backend/info.py'
--- olive/backend/info.py	2006-07-08 17:36:59 +0000
+++ olive/backend/info.py	2006-08-01 16:16:31 +0000
@@ -20,6 +20,7 @@
 import bzrlib.errors as errors
 
 from bzrlib.branch import Branch
+from bzrlib.workingtree import WorkingTree
 
 from errors import (DifferentBranchesError, NotBranchError, PrefixFormatError,
                     RevisionValueError)
@@ -222,6 +223,36 @@
     except errors.NoRepositoryPresent:
         pass
 
+def is_checkout(location):
+    """ Check if the location is a checkout.
+    
+    :param location: the location you want to check
+    
+    :return: True or False respectively
+    """
+    try:
+        branch = Branch.open_containing(location)[0]
+    except errors.NotBranchError:
+        raise NotBranchError
+    
+    try:
+        working = WorkingTree.open_containing(location)[0]
+    except:
+        raise
+    
+    working_path = working.bzrdir.root_transport.base
+    branch_path = branch.bzrdir.root_transport.base
+    
+    if working_path != branch_path:
+        # lightweight checkout
+        return True
+    elif branch.get_bound_location():
+        # checkout
+        return True
+    else:
+        return False
+
+
 def log(location, timezone='original', verbose=False, show_ids=False,
         forward=False, revision=None, log_format=None, message=None,
         long=False, short=False, line=False):

=== modified file 'olive/frontend/gtk/__init__.py'
--- olive/frontend/gtk/__init__.py	2006-07-31 18:17:48 +0000
+++ olive/frontend/gtk/__init__.py	2006-08-01 16:16:31 +0000
@@ -25,6 +25,7 @@
     pass
 try:
     import gtk
+    import gtk.gdk
     import gtk.glade
 except:
     sys.exit(1)
@@ -79,7 +80,7 @@
         self.treeview_right = self.toplevel.get_widget('treeview_right')
         self._load_left()
         self._load_right()
-    
+        
     def _load_left(self):
         """ Load data into the left panel. (Bookmarks) """
         pass
@@ -88,6 +89,9 @@
         """ Load data into the right panel. (Filelist) """
         import olive.backend.fileops as fileops
         
+        # set cursor to busy
+        self.comm.set_busy(self.treeview_right)
+        
         # Create ListStore
         liststore = gtk.ListStore(str, str, str)
         
@@ -128,6 +132,9 @@
         tvcolumn_filename.add_attribute(cell, 'text', 1)
         tvcolumn_status.pack_start(cell, True)
         tvcolumn_status.add_attribute(cell, 'text', 2)
+        
+        # set cursor to default
+        self.comm.set_busy(self.treeview_right, False)
 
 class OliveCommunicator:
     """ This class is responsible for the communication between the different
@@ -175,7 +182,9 @@
     def refresh_right(self, path=None):
         """ Refresh the file list. """
         import olive.backend.fileops as fileops
-
+        
+        self.set_busy(self.treeview_right)
+        
         if path is None:
             path = self.get_path()
 
@@ -205,3 +214,13 @@
         
         # Add the ListStore to the TreeView
         self.treeview_right.set_model(liststore)
+        
+        self.set_busy(self.treeview_right, False)
+
+    def set_busy(self, widget, busy=True):
+        if busy:
+            widget.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+        else:
+            widget.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.LEFT_PTR))
+        
+        gtk.main_iteration(0)

=== modified file 'olive/frontend/gtk/add.py'
--- olive/frontend/gtk/add.py	2006-07-21 18:18:20 +0000
+++ olive/frontend/gtk/add.py	2006-08-01 16:16:31 +0000
@@ -61,6 +61,7 @@
         
         directory = self.comm.get_path()
         
+        self.comm.set_busy(self.window)
         if radio_selected.get_active():
             # Add only the selected file
             filename = self.comm.get_selected_right()
@@ -73,6 +74,7 @@
                 fileops.add([directory + '/' + filename])
             except errors.NotBranchError:
                 dialog.error_dialog('The directory is not a branch.')
+                self.comm.set_busy(self.window, False)
                 return
             except:
                 raise
@@ -82,6 +84,7 @@
                 fileops.add([directory], True)
             except errors.NotBranchError:
                 dialog.error_dialog('The directory is not a branch.')
+                self.comm.set_busy(self.window, False)
                 return
             except:
                 raise

=== modified file 'olive/frontend/gtk/branch.py'
--- olive/frontend/gtk/branch.py	2006-07-31 18:17:48 +0000
+++ olive/frontend/gtk/branch.py	2006-08-01 16:16:31 +0000
@@ -73,29 +73,28 @@
         if revno == 0:
             revno = None
         
+        self.comm.set_busy(self.window)
         try:
-            self.comm.set_statusbar('Branching in progress, please wait...')
             init.branch(location, destination, revno)
-            self.comm.clear_statusbar()
         except errors.NonExistingSource, errmsg:
             dialog.error_dialog('Non existing source: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except errors.TargetAlreadyExists, errmsg:
             dialog.error_dialog('Target already exists: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except errors.NonExistingParent, errmsg:
             dialog.error_dialog('Parent directory doesn\'t exist: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except errors.NonExistingRevision:
             dialog.error_dialog('The given revision doesn\'t exist.')
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except errors.NotBranchError, errmsg:
             dialog.error_dialog('Not a branch: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except:
             raise

=== modified file 'olive/frontend/gtk/checkout.py'
--- olive/frontend/gtk/checkout.py	2006-07-31 18:17:48 +0000
+++ olive/frontend/gtk/checkout.py	2006-08-01 16:16:31 +0000
@@ -59,46 +59,37 @@
     def checkout(self, widget):
         from dialog import OliveDialog
         dialog = OliveDialog(self.gladefile)
-        print "DEBUG: dialog imported"
         
         entry_location = self.glade.get_widget('entry_checkout_location')
         location = entry_location.get_text()
         if location is '':
             dialog.error_dialog('You must specify a branch location.')
             return
-        print "DEBUG: got branch location:", location
         
         destination = self.filechooser.get_filename()
-        print "DEBUG: got destination:", destination
         
         spinbutton_revno = self.glade.get_widget('spinbutton_checkout_revno')
         revno = spinbutton_revno.get_value_as_int()
         if revno == 0:
             revno = None
-        print "DEBUG: got revision number:", revno
         
         checkbutton_lightweight = self.glade.get_widget('checkbutton_checkout_lightweight')
         lightweight = checkbutton_lightweight.get_active()
-        print "DEBUG: got lightweight:", lightweight
         
+        self.comm.set_busy(self.window)
         try:
-            self.comm.set_statusbar('Checkout in progress, please wait...')
-            print "DEBUG: statusbar set"
             init.checkout(location, destination, revno, lightweight)
-            print "DEBUG: checkout ended"
-            self.comm.clear_statusbar()
-            print "DEBUG: statusbar cleared"
         except errors.NotBranchError, errmsg:
             dialog.error_dialog('Not a branch: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except errors.TargetAlreadyExists, errmsg:
             dialog.error_dialog('Target already exists: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except errors.NonExistingParent, errmsg:
             dialog.error_dialog('Parent directory doesn\'t exist: %s' % errmsg)
-            self.comm.clear_statusbar()
+            self.comm.set_busy(self.window, False)
             return
         except:
             raise

=== modified file 'olive/frontend/gtk/commit.py'
--- olive/frontend/gtk/commit.py	2006-07-25 12:38:56 +0000
+++ olive/frontend/gtk/commit.py	2006-08-01 16:16:31 +0000
@@ -38,6 +38,8 @@
     """ Display Commit dialog and perform the needed actions. """
     def __init__(self, gladefile, comm):
         """ Initialize the Commit dialog. """
+        import bzrlib
+        
         self.gladefile = gladefile
         self.glade = gtk.glade.XML(self.gladefile, 'window_commit')
         
@@ -64,7 +66,10 @@
         
         # Set the delta
         self.old_tree = self.wt.branch.repository.revision_tree(self.wt.branch.last_revision())
-        self.delta = compare_trees(self.old_tree, self.wt)
+        if bzrlib.version_info[1] < 9:
+            self.delta = compare_trees(self.old_tree, self.wt)
+        else:
+            self.delta = self.wt.changes_from(self.old_tree)
         
         # Get the Commit dialog widget
         self.window = self.glade.get_widget('window_commit')
@@ -78,13 +83,22 @@
         
         # Create the file list
         self._create_file_view()
+        
+        # Some additional widgets
+        self.checkbutton_local = self.glade.get_widget('checkbutton_commit_local')
     
     def display(self):
         """ Display the Push dialog. """
         if self.notbranch:
             self.dialog.error_dialog('Directory is not a branch.')
         else:
-            self.window.show_all()
+            from olive.backend.info import is_checkout
+            if is_checkout(self.comm.get_path()):
+                # we have a checkout, so the local commit checkbox must appear
+                self.checkbutton_local.show()
+            
+            self.window.show()
+            
     
     # This code is from Jelmer Vernooij's bzr-gtk branch
     def _create_file_view(self):
@@ -136,36 +150,42 @@
         start, end = textbuffer.get_bounds()
         message = textbuffer.get_text(start, end)
         
-        checkbutton_local = self.glade.get_widget('checkbutton_commit_local')
         checkbutton_strict = self.glade.get_widget('checkbutton_commit_strict')
         checkbutton_force = self.glade.get_widget('checkbutton_commit_force')
         
         specific_files = self._get_specific_files()
         
+        self.comm.set_busy(self.window)
         # merged from Jelmer Vernooij's olive integration branch
         try:
             self.wt.commit(message, 
                            allow_pointless=checkbutton_force.get_active(),
                            strict=checkbutton_strict.get_active(),
-                           local=checkbutton_local.get_active(),
+                           local=self.checkbutton_local.get_active(),
                            specific_files=specific_files)
         except errors.NotBranchError:
             self.dialog.error_dialog('Directory is not a branch.')
+            self.comm.set_busy(self.window, False)
             return
         except errors.LocalRequiresBoundBranch:
             self.dialog.error_dialog('Local commit requires a bound branch.')
+            self.comm.set_busy(self.window, False)
             return
         except errors.PointlessCommit:
             self.dialog.error_dialog('No changes to commit. Try force commit.')
+            self.comm.set_busy(self.window, False)
             return
         except errors.ConflictsInTree:
             self.dialog.error_dialog('Conflicts in tree. Please resolve them first.')
+            self.comm.set_busy(self.window, False)
             return
         except errors.StrictCommitFailed:
             self.dialog.error_dialog('Strict commit failed. There are unknown files.')
+            self.comm.set_busy(self.window, False)
             return
         except errors.BoundBranchOutOfDate, errmsg:
             self.dialog.error_dialog('Bound branch is out of date: %s' % errmsg)
+            self.comm.set_busy(self.window, False)
             return
         except:
             raise

=== modified file 'olive/frontend/gtk/push.py'
--- olive/frontend/gtk/push.py	2006-07-31 18:17:48 +0000
+++ olive/frontend/gtk/push.py	2006-08-01 16:16:31 +0000
@@ -23,6 +23,7 @@
     pass
 try:
     import gtk
+    import gtk.gdk
     import gtk.glade
 except:
     sys.exit(1)
@@ -93,9 +94,11 @@
         radio_stored = self.glade.get_widget('radiobutton_push_stored')
         radio_specific = self.glade.get_widget('radiobutton_push_specific')
         
+        revs = 0
+        self.comm.set_busy(self.window)
         if radio_stored.get_active():
             try:
-                commit.push(self.comm.get_path())
+                revs = commit.push(self.comm.get_path())
             except errors.NotBranchError:
                 dialog.error_dialog('Directory is not a branch.')
                 return
@@ -123,15 +126,19 @@
                                    self.check_create.get_active())
             except errors.NotBranchError:
                 dialog.error_dialog('Directory is not a branch.')
+                self.comm.set_busy(self.window, False)
                 return
             except errors.NonExistingParent, errmsg:
                 dialog.error_dialog('Parent directory doesn\'t exist: %s', errmsg)
+                self.comm.set_busy(self.window, False)
                 return
             except errors.DivergedBranchesError:
                 dialog.error_dialog('Branches have been diverged.')
+                self.comm.set_busy(self.window, False)
                 return
             except errors.PathPrefixNotCreated:
                 dialog.error_dialog('Path prefix couldn\'t be created.')
+                self.comm.set_busy(self.window, False)
                 return
             except:
                 raise
@@ -139,8 +146,8 @@
             # This should really never happen
             pass
         
+        self.close()
         dialog.info_dialog('%d revision(s) pushed.' % revs)
-        self.close()
     
     def close(self, widget=None):
         self.window.destroy()

=== modified file 'olive/frontend/gtk/remove.py'
--- olive/frontend/gtk/remove.py	2006-07-21 18:18:20 +0000
+++ olive/frontend/gtk/remove.py	2006-08-01 16:16:31 +0000
@@ -49,7 +49,7 @@
         self.glade.signal_autoconnect(dic)
 
     def display(self):
-        """ Display the Add file(s) dialog. """
+        """ Display the Remove file(s) dialog. """
         self.window.show_all()
         
     def remove(self, widget):
@@ -61,6 +61,7 @@
         
         directory = self.comm.get_path()
         
+        self.comm.set_busy(self.window)
         if radio_selected.get_active():
             # Add only the selected file
             filename = self.comm.get_selected_right()
@@ -73,9 +74,11 @@
                 fileops.remove([directory + '/' + filename])
             except errors.NotBranchError:
                 dialog.error_dialog('The directory is not a branch.')
+                self.comm.set_busy(self.window, False)
                 return
             except errors.NotVersionedError:
                 dialog.error_dialog('Selected file is not versioned.')
+                self.comm.set_busy(self.window, False)
                 return
             except:
                 raise
@@ -85,9 +88,11 @@
                 fileops.remove([directory], True)
             except errors.NotBranchError:
                 dialog.error_dialog('The directory is not a branch.')
+                self.comm.set_busy(self.window, False)
                 return
             except errors.NoMatchingFiles:
                 dialog.warning_dialog('No matching files were found.')
+                self.comm.set_busy(self.window, False)
             except:
                 raise
         else:

